Release History
=============

v0.0.7
------
* Fixes to ensure proper packaging of resources instead of relying on
  submodules.

v0.0.4, v0.0.5, v0.0.6 (Unstable)
---------------------------------
* Smart pagination usage for much faster response times.
* py3 bug fixes to make it more stable.
* Provision of a way to get suggestions without password. Even though it is
  contingent on the rate limit that is applied.

v0.0.3
------
* Removal of password from command line for better security.

v0.0.2
------
* Some major bug fixes causing slowdown.


v0.0.1
------
* Long time itch to code an idea.
* First release.